==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fldapquery.1.3-1.1.2.tar.gz: ldapquery/setup.php <==
<?php


function squirrelmail_plugin_init_ldapquery() {
  global $squirrelmail_plugin_hooks;
  //global $mailbox, $imap_stream, $imapConnection;

  $squirrelmail_plugin_hooks["menuline"]["ldapquery"] =
       "ldapquery_menuline";

  $squirrelmail_plugin_hooks["options_link_and_description"]["ldapquery"] =
       "ldapquery_options";
  $squirrelmail_plugin_hooks["options_save"]["ldapquery"] = "ldapquery_save";
}

function ldapquery_menuline () {
   global $color;
   displayInternalLink ("plugins/ldapquery/ldapquery.php", "Search LDAP", "right");
   echo "&nbsp;&nbsp;\n";
}

function ldapquery_options() {
   global $color
   ?>
   <table width=50% cellpadding=3 cellspacing=0 border=0 align=center>
      <tr>
         <td bgcolor="<? echo $color[9] ?>">
            <a href="../plugins/ldapquery/options.php">Search LDAP Preferences</a>
         </td>
      </tr>
      <tr>
         <td bgcolor="<? echo $color[0] ?>">
            These settings control what type of output you will see when
            you use the Search LDAP link to search Directory Services.
         </td>
      </tr>
   </table>
   <?php
}

function ldapquery_save() {
   require_once ("../plugins/ldapquery/config.php");
   global $username,$data_dir;
   global $submit_ldapquery, $ldapquery_ldapquery_output_type;
   
   if ($submit_ldapquery) {
      if (isset($ldapquery_ldapquery_output_type)) {
         setPref($data_dir, $username, 'ldapquery_output_type',
                 $ldapquery_ldapquery_output_type);
      } else {
         setPref($data_dir, $username, 'ldapquery_output_type', 'OneTable');
      }
  
      foreach ($ldq_attributes as $attr) {
         $Var = "ldapquery_showattr_" . $attr;
         $Var2 = "ldapquery_ldapquery_showattr_" . $attr;
         global $$Var2;
         //print ("<H3>$Var - ");
         //print ($$Var2);
         //print ("</H3>");
         if (isset($$Var2)) {
            setPref($data_dir, $username, $Var, $$Var2);
         } else {
            setPref($data_dir, $username, $Var, "off");
         }
      }
  
      echo '<center>Search LDAP options saved.</center>';
   }
}

?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fldapquery.1.6-1.2.5.tar.gz: ldapquery/setup.php <==
<?php


function squirrelmail_plugin_init_ldapquery() {
  global $squirrelmail_plugin_hooks;
  //global $mailbox, $imap_stream, $imapConnection;

  $squirrelmail_plugin_hooks["menuline"]["ldapquery"] =
       "ldapquery_menuline";

  $squirrelmail_plugin_hooks["options_link_and_description"]["ldapquery"] =
       "ldapquery_options";
  $squirrelmail_plugin_hooks["options_save"]["ldapquery"] = "ldapquery_save";
}

function ldapquery_menuline () {
   global $color;
   displayInternalLink ("plugins/ldapquery/ldapquery.php", "Directory", "right");
   echo "&nbsp;&nbsp;\n";
}

function ldapquery_options() {
   global $color
   ?>
   <table width=50% cellpadding=3 cellspacing=0 border=0 align=center>
      <tr>
         <td bgcolor="<?php /* 'php' Added by ri_once */ echo $color[9] ?>">
            <a href="../plugins/ldapquery/options.php">Directory Preferences</a>
         </td>
      </tr>
      <tr>
         <td bgcolor="<?php /* 'php' Added by ri_once */ echo $color[0] ?>">
            These settings control what type of output you will see when
            you use the Directory link to search Directory Services.
         </td>
      </tr>
   </table>
   <?php
}

function ldapquery_save() {
   require_once ("../plugins/ldapquery/config.php");
   global $username,$data_dir;
   global $submit_ldapquery, $ldapquery_ldapquery_output_type;
   
   if ($submit_ldapquery) {
      if (isset($ldapquery_ldapquery_output_type)) {
         setPref($data_dir, $username, 'ldapquery_output_type',
                 $ldapquery_ldapquery_output_type);
      } else {
         setPref($data_dir, $username, 'ldapquery_output_type', 'OneTable');
      }
  
      foreach ($ldq_attributes as $attr) {
         $Var = "ldapquery_showattr_" . $attr;
         $Var2 = "ldapquery_ldapquery_showattr_" . $attr;
         global $$Var2;
         //print ("<H3>$Var - ");
         //print ($$Var2);
         //print ("</H3>");
         if (isset($$Var2)) {
            setPref($data_dir, $username, $Var, $$Var2);
         } else {
            setPref($data_dir, $username, $Var, "off");
         }
      }
  
      echo '<center>Directory options saved.</center>';
   }
}

?>
